<template>
    <div
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="markLoading"
    >
        <el-dialog
            :title="title"
            :visible="visible"
            :before-close="handleClose"
            :close-on-click-modal="false"
            :destroy-on-close="true"
            width="90%"
            top="5vh"
            :class="[reqLoading ? 'dialog-box' : '']"
        >
            <div
                style="width: 100%"
                v-loading="reqLoading"
                element-loading-text="加载中..."
                element-loading-spinner="el-icon-loading"
                element-loading-background="rgba(255, 255, 255, 1)"
            >
                <addForm
                    :judgmentDetail="title !== '详情'"
                    ref="addRorm"
                    @offMark="offMark"
                    @closeDialog="handleClose"
                ></addForm>
            </div>
            <span
                slot="footer"
                class="dialog-footer"
                :style="reqLoading ? 'position: relative;z-index: -1;' : ''"
            >
                <!-- <el-button v-if="title === '编辑' && $route.name !== 'CityReformSituationPropel'" type="primary"
                        @click="editSavePropel">保存</el-button> -->
                <template v-if="title === '审核'">
                    <el-button type="primary" @click="handleVerify"
                        >通过</el-button
                    >
                    <el-button type="danger" @click="handleReject"
                        >驳回</el-button
                    >
                </template>
                <el-button
                    v-if="title === '编辑'"
                    type="primary"
                    @click="handelSave"
                    >保存</el-button
                >
                <el-button @click="handleClose">取消</el-button>
            </span>
        </el-dialog>
    </div>
</template>

<script>
import addForm from './addForm.vue'
import RejectInfoBlockDialog from '@/components/dialog/RejectInfoBlockDialog.vue'
import UploadFile from '@/components/uploadFile/index.vue'
import FileList from '@/components/uploadFile/FileList.vue'
import moment from 'moment'
import {TableMixin} from '@/mixins/tableMixin'
import {file, files} from 'jszip'
import apis from '@/api/ReformSituation/index.js'
export default {
    name: 'projectsDialog',
    components: {
        addForm,
    },
    mixins: [TableMixin],
    data() {
        return {
            title: '推进录入',
            visible: false,
            markLoading: false,
            reqLoading: false,
            parameter: {},
            allTreeData: [],
            treeData: [],
            coreIndex: [],
            rules: {
                projectName: [
                    {
                        required: true,
                        message: '请输入项目名称',
                        trigger: 'change',
                    },
                ],
                groupName: [
                    {
                        required: true,
                        message: '请选择专项小组',
                        trigger: 'change',
                    },
                ],
                unitId: [
                    {
                        required: true,
                        message: '请选择牵头单位',
                        trigger: 'change',
                    },
                ],
            },
            cooperateUnit: [],
            base: {},
            progress: {},
            projectInfo: {},
        }
    },
    created() {
        let data = JSON.parse(
            JSON.stringify(
                JSON.parse(sessionStorage.getItem('responsibilityTree'))
            )
        )
        this.treeData = data[0].children[0].children[0].children
    },
    mounted() {},
    methods: {
        offMark() {
            this.reqLoading = false
        },
        // -----------项目创建录入-----------------
        open(data, title) {
            this.visible = true
            this.title = title
            this.$nextTick(() => {
                this.reqLoading = true
                this.$refs.addRorm.getDetailById(data.id)
            })
        },
        handelSave() {
            let msg = '保存修改'
            this.$confirm(`确认${msg}吗？`, this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'success',
            }).then(() => {
                let status = this.$refs.addRorm.infoData.status
                this.$refs.addRorm.submitData(status, msg)
            })
        },
        // 审核通过
        handleVerify() {
            this.$refs.addRorm.handleVerify(5)
        },

        // 驳回确认
        handleReject() {
            this.$refs.addRorm.handleReject()
        },
        handleClose() {
            this.$emit('refreshData')
            this.visible = false
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.file-box {
    flex: 1;

    /deep/.file-item {
        box-sizing: border-box;
        overflow: hidden;

        a {
            margin: 0;

            &:nth-child(2) {
                margin: 0 5px;
            }
        }
    }
}

.file-td {
    text-align: left;

    >div {
        display: flex;
        align-items: center;
        gap: 10px;
        font-size: 16px;

        a {
            margin-top: 5px;
            padding: 0 5px 0 5px;

            /deep/.el-link--inner {
                font-size: 16px;
            }
        }

        .tip {
            font-size: 14px;
            color: #F56C6C;
        }
    }
}

.list-td {
    position: relative;
    text-align: left;
    padding-bottom: 0;

    >i {
        cursor: pointer;
        position: absolute;
        right: 0px;
        bottom: 0px;
        width: 40PX;
        height: 20px;
        border: 1px solid #dcdfe6;
        line-height: 20px;
        text-align: center;
        border-top-left-radius: 5px;
        border-right: 0;
        border-bottom: 0;

        &:hover {
            color: #409EFF;
            border-color: #409EFF;
        }
    }
}



.table-title {
    font-size: 20px;
    font-weight: bold;
    padding-bottom: 10px;
    letter-spacing: 2px;
}

th,
td {
    height: 40px;
    padding: 5px;
    text-align: center;
    font-size: 15px;
}

td {
    font-size: 15px;
}

.text-list {

    margin-bottom: 5px;
    box-sizing: border-box;

    li {
        width: calc(100% - 40PX);
        display: flex;
        align-items: center;
        justify-content: space-between;
        padding: 5px;
        box-sizing: border-box;
        border-radius: 5px;
        position: relative;

        .text-input {
            display: flex;
            align-items: center;
            flex: 1;
            gap: 5px;
            transition: all .3s;

            /deep/.el-textarea__inner {
                font-size: 15px;
            }

            /deep/a {
                cursor: pointer;

                span {
                    width: 40PX;
                    text-align: center;
                }

                width: fit-content;
            }
        }

        .text-value {
            width: 100%;
        }
    }
}

.inside-table {
    padding: 0;
    margin: 0;
    border-collapse: collapse;

    tr {
        border: none;
        border-bottom: 2px solid;

        th {
            border-right: 2px solid;

            /deep/.el-button {
                border: 1px solid #dcdfe6;

                &:hover {
                    border-color: #bed0ff;
                }
            }
        }

        td {
            text-align: center;
            border: none;
            border-right: 2px solid;
        }

        >:last-child {
            border: none;
        }

        &:last-child {
            border: none;
        }
    }


}

/deep/.file-item {
    .file_name {
        max-width: 70%;
        height: auto;
        font-size: 16px !important;
    }
}

/deep/.el-radio {
    margin-right: 0px;
}

.add-btn {
    font-weight: bold;
    cursor: pointer;
    color: $--color-primary;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/.el-dialog__body {
    max-height: 75vh;
    overflow-y: auto;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}

.timePicker {
    /deep/.el-input__inner {
        width: 100px !important;
    }
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-box {
    /deep/.el-dialog__body {
        overflow: hidden;
    }
}

.my-el-table {
    /deep/.el-form-item {
        margin-bottom: 0;
    }

    /deep/.el-form-item.is-error {
        margin-bottom: 0;
    }
}
</style>